Test website

## Form GET

This page showcase a situation where someone used a form with a combobox to enable navigation on the website.

Nota: this has been seen in the wild on https://chopin.lib.uchicago.edu/ (open any title scores and the combobox will appear in top right corner) and on https://medecine-integree.com/ (for which we - Kiwix - do not have any rights to copy but have been approached by a user).

### Rewrite

Server configuration will intercept the queryparameter and rewrite internal to proper HTML file, invisible to the end user.

Select a subpage to open :

### Redirect

Server configuration will intercept the queryparameter and redirect with a 302 to proper URL, hence visible to the end user.

Select a subpage to open :